'use server';

import { FetchDataSteps } from '@/components/default/tutorial';
import { InfoIcon } from 'lucide-react';
import { getUser } from '@/lib/actions';
import type { User } from '@/utils/supabase';
import Link from 'next/link';
import { TestSentryCard } from '@/components/default/sentry';
import {
  Button,
  Card,
  CardContent,
  CardDescription,
  CardHeader,
  CardTitle,
  Separator,
} from '@/components/ui';

const HomePage = async () => {
  const response = await getUser();
  if (!response.success || !response.data) {
    return (
      <main className='w-full items-center justify-center'>
        <div className='flex flex-col p-5 items-center justify-center space-y-6'>
          <Card className='md:min-w-2xl'>
            <CardHeader className='flex flex-col items-center'>
              <CardTitle className='text-3xl'>
                Welcome to the T3 Supabase Template!
              </CardTitle>
              <CardDescription className='text-[1.0rem] mb-2'>
                A great place to start is by creating a new user account &
                ensuring you can sign in!
              </CardDescription>
              <Button
                asChild
                size='sm'
                variant={'default'}
                className='w-1/3 items-center'
              >
                <Link href='/sign-up'>Sign up</Link>
              </Button>
            </CardHeader>
            <Separator className='bg-accent' />
            <CardContent className='flex flex-col px-5 py-2 items-center justify-center'>
              <CardTitle className='text-lg mb-6 w-2/3 text-center'>
                You can also test out your connection to Sentry if you want to
                start there!
              </CardTitle>
              <TestSentryCard />
            </CardContent>
          </Card>
        </div>
      </main>
    );
  }
  const user: User = response.data;
  return (
    <div className='flex-1 w-full flex flex-col gap-12'>
      <div className='w-full'>
        <div
          className='bg-accent text-sm p-3 px-5
          rounded-md text-foreground flex gap-3 items-center'
        >
          <InfoIcon size='16' strokeWidth={2} />
          This is a protected component that you can only see as an
          authenticated user
        </div>
      </div>
      <div className='flex flex-col gap-2 items-start'>
        <h2 className='font-bold text-3xl mb-4'>Your user details</h2>
        <pre
          className='text-sm font-mono p-3 rounded
          border max-h-50 overflow-auto'
        >
          {JSON.stringify(user, null, 2)}
        </pre>
      </div>
      <TestSentryCard />
      <div>
        <h2 className='font-bold text-2xl mb-4'>Next steps</h2>
        <FetchDataSteps />
      </div>
    </div>
  );
};
export default HomePage;
